@@ -11,6 +11,7 @@ use Bio::Perl;
 use Bio::MLST::Blast::Database;
 use Bio::MLST::Blast::BlastN;
 use Bio::MLST::Types;
+use Bio::MLST::SequenceType;
 
 has 'sequence_filename'      => ( is => 'ro', isa => 'Bio::MLST::File',      required => 1 );
 has 'allele_filenames'       => ( is => 'ro', isa => 'ArrayRef', required => 1 );
@@ -27,6 +28,7 @@ has 'contamination'          => ( is => 'rw', isa => 'Bool',    default => 0);
 has 'contamination_sequence_names' => ( is => 'rw', isa => 'Maybe[ArrayRef]' );
 has 'new_st'                 => ( is => 'rw', isa => 'Bool',    default => 0);
 has '_absent_loci'           => ( is => 'ro', isa => 'HashRef', lazy => 1, builder => '_build__absent_loci' );
+has 'profiles_filename'     => ( is => 'ro', isa => 'Bio::MLST::File',        required => 1 ); 
 
 sub _build__blast_db_location
 {
@@ -112,7 +114,7 @@ sub _build_matching_sequences
     if(defined($top_blast_hit{contamination}))
     {
       $self->contamination(1);
-      $self->contamination_sequence_names($top_blast_hit{contamination});
+      $self->_translate_contamination_names_into_sequence_types($top_blast_hit{contamination},$top_blast_hit{allele_name});
     }
     
     $top_blast_hit{allele_name} =~ s![-_]+!-!g;
@@ -145,6 +147,29 @@ sub _build_matching_sequences
   return \%matching_sequence_names;
 }
 
+sub _translate_contamination_names_into_sequence_types
+{
+  my ($self, $contamination_names, $main_allele_name) = @_;
+  my @contamination_sequence_types;
+  
+  for my $allele_number (@{ $contamination_names})
+  {
+    next if($main_allele_name eq $allele_number);
+    my $st = Bio::MLST::SequenceType->new(
+      profiles_filename => $self->profiles_filename,
+      sequence_names => [$allele_number]
+    );
+    
+    if(defined($st->sequence_type()) )
+    {
+      push(@contamination_sequence_types, $st->sequence_type());
+    }
+  }
+  
+  $self->contamination_sequence_names(\@contamination_sequence_types);
+}
+
+
 sub _get_blast_hit_sequence
 {
    my ($self, $contig_name, $start, $end, $word_size, $reverse_complement) = @_;
@@ -225,7 +250,7 @@ Bio::MLST::CompareAlleles - Get a list of matching alleles between the sequence
 
 =head1 VERSION
 
-version 1.130660
+version 1.133090
 
 =head1 SYNOPSIS
 
