@@ -44,7 +44,8 @@ sub _build__compare_alleles
     sequence_filename => $self->fasta_file,
     allele_filenames  => $self->_search_results->allele_filenames(),
     makeblastdb_exec  => $self->makeblastdb_exec,
-    blastn_exec       => $self->blastn_exec
+    blastn_exec       => $self->blastn_exec,
+    profiles_filename => $self->_search_results->profiles_filename()
   );
   
   my $output_fasta = Bio::MLST::OutputFasta->new(
@@ -92,7 +93,7 @@ Bio::MLST::ProcessFasta - Take in a fasta file, lookup the MLST database and cre
 
 =head1 VERSION
 
-version 1.130660
+version 1.133090
 
 =head1 SYNOPSIS
 
